@@ -63,6 +63,7 @@ void Service::init()
     ServerConfigManager::instance()->initServerConfig();
     // 主进程：首次赋值m_pShareMemoryInfo
     listenWindowEffectSwitcher();
+    listenDebuginfodOption();
 }
 
 void Service::releaseInstance()
@@ -111,6 +112,8 @@ void Service::initSetting()
 
     //判断未开启窗口特效时，隐藏透明度/背景模糊选项
     showHideOpacityAndBlurOptions(DWindowManagerHelper::instance()->hasComposite());
+    // 根据是否开启debuginfod选项初始化debuginfod urls选项的显示与否
+    showHideDebuginfodUrlsOptions(Settings::instance()->enableDebuginfod());
 }
 
 void Service::slotSettingsDialogFinished(int result)
@@ -192,6 +195,42 @@ void Service::showHideOpacityAndBlurOptions(bool isShow)
     }
 }
 
+void Service::showHideDebuginfodUrlsOptions(bool isShow)
+{
+    QWidget *rightFrame = m_settingDialog->findChild<QWidget *>("RightFrame");
+    if (nullptr == rightFrame) {
+        qInfo() << "can not found RightFrame in QWidget";
+        return;
+    }
+
+    QList<QWidget *> rightWidgetList = rightFrame->findChildren<QWidget *>();
+    for (int i = 0; i < rightWidgetList.size(); i++) {
+        QWidget *widget = rightWidgetList.at(i);
+        if (nullptr == widget)
+            continue;
+
+        if (strcmp(widget->metaObject()->className(), "QLabel") == 0) {
+            QString text = (qobject_cast<QLabel *>(widget))->text();
+            if (QObject::tr("debuginfod URLs") == text) {
+                QWidget *optionWidget = widget;
+                QWidget *parentWidget = widget->parentWidget();
+                QWidget *wrapWidget = parentWidget ? parentWidget->parentWidget() : nullptr;
+                if (wrapWidget && strcmp(wrapWidget->metaObject()->className(), "QWidget") == 0) {
+                    wrapWidget->setVisible(isShow);
+                }
+
+                if (parentWidget && strcmp(parentWidget->metaObject()->className(), "Dtk::Widget::DFrame") == 0)
+                    optionWidget = parentWidget;
+
+                if (isShow)
+                    optionWidget->show();
+                else
+                    optionWidget->hide();
+            }
+        }
+    }
+}
+
 void Service::listenWindowEffectSwitcher()
 {
     connect(DWindowManagerHelper::instance(), &DWindowManagerHelper::hasCompositeChanged, this, [this]() {
@@ -201,6 +240,15 @@ void Service::listenWindowEffectSwitcher()
     });
 }
 
+void Service::listenDebuginfodOption()
+{
+    connect(Settings::instance(), &Settings::terminalSettingChanged, this, [this] (const QString &keyName) {
+        if ("advanced.debuginfod.enable_debuginfod" == keyName) {
+            showHideDebuginfodUrlsOptions(Settings::instance()->enableDebuginfod());
+        }
+    });
+}
+
 qint64 Service::getEntryTime()
 {
     return m_entryTime;
